<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="CBS Editor" version="1" translationDomain="calligraplanlibs">
    <MenuBar>
        <Menu name="edit">
            <Action name="add_account"/>
            <Action name="add_subaccount"/>
            <Action name="delete_selection"/>
        </Menu>
        <Menu name="view">
            <Separator/>
            <Action name="expand_all"/>
            <Action name="collapse_all"/>
            <Separator/>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
    </MenuBar>

    <ToolBar name="cbseditorToolBar" fullWidth="false" noMerge="1"><Text>Tools</Text>
        <Action name="add_account"/>
        <Action name="add_subaccount"/>
        <Action name="delete_selection"/>
    </ToolBar>
</gui>
