<!DOCTYPE gui SYSTEM "kpartgui.dtd" >
<gui name="Portfolio" version="57" translationDomain="calligraplanportfolio">
    <MenuBar>
        <Menu name="file" NoMerge="1"><text>&amp;File</text>
            <Action name="file_new" />
            <Action name="activeauthor" />
            <Action name="file_open" />
            <Action name="file_open_recent" />
            <Separator />
            <Action name="file_save" />
            <Action name="file_save_as" />
            <Action name="file_reload_file" />
            <Action name="file_versions_file"/>
            <Separator />
            <Action name="file_send_file" />
            <Separator />
            <Merge/>
            <Separator/>
            <Action name="file_createtemplate"/>
            <Action name="file_createnewproject"/>
            <Separator/>
            <Action name="file_documentinfo" />
            <DefineGroup name="file_infos" />
            <Action name="file_close" group="file_close"/>
        </Menu>
       <Menu name="edit" NoMerge="1"><text>&amp;Edit</text>
            <Action name="edit_undo"/>
            <Action name="edit_redo"/>
            <Separator/>
<!--             <Action name="edit_cut"/> -->
            <Action name="edit_copy"/>
            <Action name="edit_paste"/>
            <Separator/> 
        </Menu>
        <Menu name="view" NoMerge="1"><text>&amp;View</text>
            <Action name="view_newview"/>
            <Separator/>
            <ActionList name="viewmenu"/>
        </Menu>
        <Menu name="help" NoMerge="1"><text>&amp;Help</text>
            <Action name="plan_introduction"/>
        </Menu>
    </MenuBar>
    <ToolBar name="mainToolBar" fullWidth="false"><text>File</text>
        <Action name="file_new" />
        <Action name="file_open" />
        <Action name="file_save" />
    </ToolBar>
    <ToolBar name="edit_toolbar" fullWidth="false"><text>Edit</text>
    </ToolBar>
</gui>
