<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE kpartgui>
<gui name="Resource Assignments" version="3" translationDomain="calligraplanlibs">
    <MenuBar>
        <Menu name="view">
            <Separator/>
            <Action name="expand_all"/>
            <Action name="collapse_all"/>
            <Separator/>
            <Action name="show_project"/>
            <Action name="split_view"/>
            <Separator/>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
<!--        <Menu name="edit"><text>&amp;Edit</text>
            <Action name="task_progress"/>
            <Action name="task_description"/>
            <Action name="task_documents"/>
        </Menu>-->
    </MenuBar>

    <ToolBar name="resourceassignmentsToolBar" fullWidth="false" noMerge="1"><Text>Tools</Text>
    </ToolBar>

    <Menu name="taskview_popup">
        <Action name="task_progress"/>
        <Action name="task_description"/>
        <Action name="task_documents"/>
    </Menu>
</gui>
