<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="Gantt Summary View" version="2" translationDomain="calligraplanportfolio">
    <MenuBar>
        <Menu name="view"><text>&amp;View</text>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
    </MenuBar>
    <ToolBar name="ganttsummaryviewToolBar"  fullWidth="false"><text>Tools</text>
    </ToolBar>
    <Menu name="gantt_project_context_menu">
        <Action name="gantt_open_project"/>
        <Separator/>
        <Action name="print"/>
        <Action name="print_preview"/>
        <Action name="print_pdf"/>
        <Action name="print_options"/>
        <Separator/>
        <Action name="configure_view"/>
    </Menu>
    <Menu name="gantt_context_menu"><text>&amp;View</text>
        <Action name="print"/>
        <Action name="print_preview"/>
        <Action name="print_pdf"/>
        <Action name="print_options"/>
        <Separator/>
        <Action name="configure_view"/>
    </Menu>
</gui>
