<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="Task Editor" version="4" translationDomain="calligraplanlibs">
    <MenuBar>
        <Menu name="edit">
            <Action name="add_task"/>
            <Action name="add_subtask"/>
            <Action name="delete_task"/>
            <Separator/>
            <Action name="link_task"/>
            <Action name="split_task"/>
            <Separator/>
            <Action name="indent_task"/>
            <Action name="unindent_task"/>
            <Action name="move_task_up"/>
            <Action name="move_task_down"/>
        </Menu>
        <Menu name="view">
            <Separator/>
            <Action name="expand_all"/>
            <Action name="collapse_all"/>
            <Separator/>
            <Action name="show_project"/>
            <Action name="split_view"/>
            <Separator/>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
    </MenuBar>

    <ToolBar name="taskeditorToolBar" fullWidth="false" noMerge="1"><Text>Tools</Text>
        <Action name="add_task"/>
        <Action name="add_subtask"/>
        <Action name="delete_task"/>
        <Separator/>
        <Action name="link_task"/>
        <Action name="split_task"/>
        <Separator/>
        <Action name="indent_task"/>
        <Action name="unindent_task"/>
        <Action name="move_task_up"/>
        <Action name="move_task_down"/>
    </ToolBar>

    <Menu name="task_edit_popup">
        <Action name="node_properties"/>
    </Menu>
    <Menu name="task_popup">
        <Action name="node_properties"/>
        <Action name="task_progress"/>
    </Menu>
    <Menu name="summarytask_popup">
        <Action name="node_properties"/>
    </Menu>
    <Menu name="taskeditor_milestone_popup">
        <Action name="node_properties"/>
        <Action name="task_progress"/>
    </Menu>
</gui>
