<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="Progress View" version="2" translationDomain="calligraplanportfolio">
    <MenuBar>
       <Menu name="view"><text>&amp;View</text>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
    </MenuBar>
<!--    <ToolBar name="progressviewToolBar"  fullWidth="false"><text>Tools</text>
    </ToolBar>-->
</gui>
