<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE kpartgui>
<gui name="Generate Reports" version="1" translationDomain="calligraplanlibs">
    <MenuBar>
        <Menu name="edit">
            <Action name="add_report"/>
            <Action name="remove_report"/>
            <Action name="generate_report"/>
        </Menu>
        <Menu name="view">
            <Separator/>
            <Action name="expand_all"/>
            <Action name="collapse_all"/>
            <Separator/>
            <Action name="print"/>
            <Action name="print_preview"/>
            <Action name="print_pdf"/>
            <Action name="print_options"/>
            <Separator/>
            <Action name="configure_view"/>
        </Menu>
    </MenuBar>

    <ToolBar name="generatereportsToolBar" fullWidth="false" noMerge="1"><Text>Tools</Text>
        <Action name="add_report"/>
        <Action name="remove_report"/>
        <Action name="generate_report"/>
    </ToolBar>
    <Menu name="generatereports_popup">
        <Action name="open_report"/>
    </Menu>
</gui>
