<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="Calligra Plan" version="1" translationDomain="calligraplan">
    <MenuBar>
        <Menu name="file" noMerge="1"><text>&amp;File</text>
            <DefineGroup name="file_top"/>
            <Merge/>
            <Separator />
            <DefineGroup name="file_close"/>
            <Action name="file_quit" />
        </Menu>
        <Merge />
        <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
            <DefineGroup name="settings_top"/>
            <Separator/>
            <Merge/>
            <Action name="options_configure_toolbars"/>
            <Action name="options_configure_keybinding"/>
            <Action name="theme_menu" />
            <Separator/>
            <DefineGroup name="settings_configure"/>
            <Action name="switch_application_language"/>
            <Action name="configure"/>
        </Menu>
        <Menu name="help" NoMerge="1"><text>&amp;Help</text>
            <Action name="help_contents"/>
            <Action name="help_whats_this"/>
            <MergeLocal name="help_whats_this_merge"/>
            <Separator/>
            <MergeLocal/>
            <Action name="help_show_tip"/>
            <Separator/>
            <Action name="help_report_bug"/>
            <Separator/>
            <Action name="help_donate"/>
            <Separator/>
            <MergeLocal name="about_merge"/>
            <Action name="help_about_app"/>
            <Action name="help_about_kde"/>
        </Menu>
    </MenuBar>
</gui>
